@@ -28,11 +28,9 @@ from starlite.constants import REDIRECT_STATUS_CODES
 from starlite.datastructures import (
     BackgroundTask,
     BackgroundTasks,
-    Cookie,
     File,
     Redirect,
     ResponseContainer,
-    ResponseHeader,
 )
 from starlite.enums import HttpMethod, MediaType
 from starlite.exceptions import (
@@ -51,10 +49,13 @@ from starlite.types import (
     CacheKeyBuilder,
     Empty,
     EmptyType,
-    ExceptionHandler,
+    ExceptionHandlersMap,
     Guard,
     Method,
     Middleware,
+    ResponseCookies,
+    ResponseHeadersMap,
+    ResponseType,
 )
 from starlite.utils import AsyncCallable, is_async_callable, is_class_and_subclass
 
@@ -66,7 +67,7 @@ if TYPE_CHECKING:
     from starlite.types import AsyncAnyCallable
 
 
-def _normalize_cookies(local_cookies: List["Cookie"], layered_cookies: List["Cookie"]) -> List[Dict[str, Any]]:
+def _normalize_cookies(local_cookies: "ResponseCookies", layered_cookies: "ResponseCookies") -> List[Dict[str, Any]]:
     """Given two lists of cookies, ensures the uniqueness of cookies by key and
     returns a normalized dict ready to be set on the response."""
     filtered_cookies = [*local_cookies]
@@ -80,7 +81,7 @@ def _normalize_cookies(local_cookies: List["Cookie"], layered_cookies: List["Coo
     return normalized_cookies
 
 
-def _normalize_headers(headers: Dict[str, "ResponseHeader"]) -> Dict[str, Any]:
+def _normalize_headers(headers: "ResponseHeadersMap") -> Dict[str, Any]:
     """Given a dictionary of ResponseHeader, filters them and returns a
     dictionary of values.
 
@@ -126,7 +127,7 @@ async def _normalize_response_data(data: Any, plugins: List["PluginProtocol"]) -
 
 def _create_response_container_handler(
     after_request: Optional["AfterRequestHandler"],
-    cookies: List["Cookie"],
+    cookies: "ResponseCookies",
     headers: Dict[str, Any],
     media_type: str,
     status_code: int,
@@ -145,7 +146,7 @@ def _create_response_container_handler(
 
 
 def _create_response_handler(
-    after_request: Optional["AfterRequestHandler"], cookies: List["Cookie"]
+    after_request: Optional["AfterRequestHandler"], cookies: "ResponseCookies"
 ) -> "AsyncAnyCallable":
     """Creates a handler function for Starlite Responses."""
 
@@ -159,7 +160,7 @@ def _create_response_handler(
 
 
 def _create_starlette_response_handler(
-    after_request: Optional["AfterRequestHandler"], cookies: List["Cookie"]
+    after_request: Optional["AfterRequestHandler"], cookies: "ResponseCookies"
 ) -> "AsyncAnyCallable":
     """Creates a handler function for Starlette Responses."""
 
@@ -175,10 +176,10 @@ def _create_starlette_response_handler(
 def _create_data_handler(
     after_request: Optional["AfterRequestHandler"],
     background: Optional[Union["BackgroundTask", "BackgroundTasks"]],
-    cookies: List["Cookie"],
+    cookies: "ResponseCookies",
     headers: Dict[str, Any],
     media_type: str,
-    response_class: Type[Response],
+    response_class: "ResponseType",
     status_code: int,
 ) -> "AsyncAnyCallable":
     """Creates a handler function for arbitrary data."""
@@ -245,15 +246,15 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         cache: Union[bool, int] = False,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
-        exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
+        exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         http_method: Union[HttpMethod, Method, List[Union[HttpMethod, Method]]],
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
         opt: Optional[Dict[str, Any]] = None,
-        response_class: Optional[Type[Response]] = None,
-        response_cookies: Optional[List[Cookie]] = None,
-        response_headers: Optional[Dict[str, ResponseHeader]] = None,
+        response_class: Optional[ResponseType] = None,
+        response_cookies: Optional[ResponseCookies] = None,
+        response_headers: Optional[ResponseHeadersMap] = None,
         status_code: Optional[int] = None,
         sync_to_thread: bool = False,
         # OpenAPI related attributes
@@ -289,7 +290,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
                 of seconds (e.g. '120') to cache the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
-            dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.provide.Provide] instances.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             http_method: An [http method string][starlite.types.Method], a member of the enum
@@ -396,7 +397,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
                 response_class = layer.response_class
         return response_class
 
-    def resolve_response_headers(self) -> Dict[str, "ResponseHeader"]:
+    def resolve_response_headers(self) -> "ResponseHeadersMap":
         """Returns all header parameters in the scope of the handler function.
 
         Returns:
@@ -407,7 +408,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             resolved_response_headers.update(layer.response_headers or {})
         return resolved_response_headers
 
-    def resolve_response_cookies(self) -> List["Cookie"]:
+    def resolve_response_cookies(self) -> "ResponseCookies":
         """Returns a list of Cookie instances. Filters the list to ensure each
         cookie key is unique.
 
@@ -415,10 +416,10 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             A list of [Cookie][starlite.datastructures.Cookie] instances.
         """
 
-        cookies: List["Cookie"] = []
+        cookies: "ResponseCookies" = []
         for layer in self.ownership_layers:
             cookies.extend(layer.response_cookies or [])
-        filtered_cookies: List["Cookie"] = []
+        filtered_cookies: "ResponseCookies" = []
         for cookie in reversed(cookies):
             if not any(cookie.key == c.key for c in filtered_cookies):
                 filtered_cookies.append(cookie)
@@ -589,14 +590,14 @@ class get(HTTPRouteHandler):
         cache: Union[bool, int] = False,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
-        exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
+        exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
         opt: Optional[Dict[str, Any]] = None,
-        response_class: Optional[Type[Response]] = None,
-        response_cookies: Optional[List[Cookie]] = None,
-        response_headers: Optional[Dict[str, ResponseHeader]] = None,
+        response_class: Optional[ResponseType] = None,
+        response_cookies: Optional[ResponseCookies] = None,
+        response_headers: Optional[ResponseHeadersMap] = None,
         status_code: Optional[int] = None,
         sync_to_thread: bool = False,
         # OpenAPI related attributes
@@ -632,7 +633,7 @@ class get(HTTPRouteHandler):
                 of seconds (e.g. '120') to cache the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
-            dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.provide.Provide] instances.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -709,14 +710,14 @@ class post(HTTPRouteHandler):
         cache: Union[bool, int] = False,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
-        exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
+        exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
         opt: Optional[Dict[str, Any]] = None,
-        response_class: Optional[Type[Response]] = None,
-        response_cookies: Optional[List[Cookie]] = None,
-        response_headers: Optional[Dict[str, ResponseHeader]] = None,
+        response_class: Optional[ResponseType] = None,
+        response_cookies: Optional[ResponseCookies] = None,
+        response_headers: Optional[ResponseHeadersMap] = None,
         status_code: Optional[int] = None,
         sync_to_thread: bool = False,
         # OpenAPI related attributes
@@ -752,7 +753,7 @@ class post(HTTPRouteHandler):
                 of seconds (e.g. '120') to cache the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
-            dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.provide.Provide] instances.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -829,14 +830,14 @@ class put(HTTPRouteHandler):
         cache: Union[bool, int] = False,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
-        exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
+        exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
         opt: Optional[Dict[str, Any]] = None,
-        response_class: Optional[Type[Response]] = None,
-        response_cookies: Optional[List[Cookie]] = None,
-        response_headers: Optional[Dict[str, ResponseHeader]] = None,
+        response_class: Optional[ResponseType] = None,
+        response_cookies: Optional[ResponseCookies] = None,
+        response_headers: Optional[ResponseHeadersMap] = None,
         status_code: Optional[int] = None,
         sync_to_thread: bool = False,
         # OpenAPI related attributes
@@ -872,7 +873,7 @@ class put(HTTPRouteHandler):
                 of seconds (e.g. '120') to cache the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
-            dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.provide.Provide] instances.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -949,14 +950,14 @@ class patch(HTTPRouteHandler):
         cache: Union[bool, int] = False,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
-        exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
+        exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
         opt: Optional[Dict[str, Any]] = None,
-        response_class: Optional[Type[Response]] = None,
-        response_cookies: Optional[List[Cookie]] = None,
-        response_headers: Optional[Dict[str, ResponseHeader]] = None,
+        response_class: Optional[ResponseType] = None,
+        response_cookies: Optional[ResponseCookies] = None,
+        response_headers: Optional[ResponseHeadersMap] = None,
         status_code: Optional[int] = None,
         sync_to_thread: bool = False,
         # OpenAPI related attributes
@@ -992,7 +993,7 @@ class patch(HTTPRouteHandler):
                 of seconds (e.g. '120') to cache the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
-            dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.provide.Provide] instances.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -1069,14 +1070,14 @@ class delete(HTTPRouteHandler):
         cache: Union[bool, int] = False,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
-        exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
+        exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
         opt: Optional[Dict[str, Any]] = None,
-        response_class: Optional[Type[Response]] = None,
-        response_cookies: Optional[List[Cookie]] = None,
-        response_headers: Optional[Dict[str, ResponseHeader]] = None,
+        response_class: Optional[ResponseType] = None,
+        response_cookies: Optional[ResponseCookies] = None,
+        response_headers: Optional[ResponseHeadersMap] = None,
         status_code: Optional[int] = None,
         sync_to_thread: bool = False,
         # OpenAPI related attributes
@@ -1112,7 +1113,7 @@ class delete(HTTPRouteHandler):
                 of seconds (e.g. '120') to cache the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
-            dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.provide.Provide] instances.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
