@@ -21,9 +21,8 @@ if TYPE_CHECKING:
 def create_path_item(
     route: "HTTPRoute", create_examples: bool, plugins: List["PluginProtocol"], use_handler_docstrings: bool
 ) -> PathItem:
-    """
-    Create a PathItem model for the given route parsing all http_methods into Operation Models
-    """
+    """Create a PathItem model for the given route parsing all http_methods
+    into Operation Models."""
     path_item = PathItem()
     for http_method, handler_tuple in route.route_handler_map.items():
         route_handler, _ = handler_tuple
@@ -65,8 +64,7 @@ def create_path_item(
 
 
 def get_description_for_handler(route_handler: "HTTPRouteHandler", use_handler_docstrings: bool) -> Optional[str]:
-    """
-    Produces the operation description for the handler.
+    """Produces the operation description for the handler.
 
     Args:
         route_handler (HTTPRouteHandler)
